package bodycheck

import (
	"errors"
	"spaceofcheng/services/models/bodycheck"
	"spaceofcheng/services/models/model"
	"spaceofcheng/services/utils"
)

// BodycheckServ 系统处理
type BodycheckServ struct {
	ctx *utils.Context
	dao *bodycheck.DAO
}

// NewBodycheckServ 初始化
func NewBodycheckServ(ctx *utils.Context) *BodycheckServ {
	return &BodycheckServ{
		ctx: ctx,
		dao: bodycheck.NewDAO(ctx),
	}
}
func (s *BodycheckServ) GetBodyCheckByUser(userID int) ([]model.TaBodyCheck, error) {
	bodychecks, err := s.dao.GetBodyCheckByUser(userID)
	if err != nil {
		utils.LogError("查询用户体检信息失败: " + err.Error())
		return nil, errors.New("查询用户体检信息失败")
	}
	return bodychecks, nil
}
func (s *BodycheckServ) GetCheckSpecs() ([]model.TdCheckSpec, error) {
	specs, err := s.dao.GetCheckSpecs()
	if err != nil {
		utils.LogError("获取项目指标信息失败: " + err.Error())
		return nil, errors.New("获取项目指标信息失败")
	}
	return specs, nil
}
func (s *BodycheckServ) GetCheckByUserAndEquipmentID(userID int, EquipmentID string) (*model.TaBodyCheck, error) {
	check, err := s.dao.GetCheckByUserAndEquipmentID(userID, EquipmentID)
	if err != nil {
		utils.LogError("根据用户与设备ID获取体检信息失败: " + err.Error())
		return nil, errors.New("根据用户与设备ID获取体检信息失败")
	}
	return check, nil
}
func (s *BodycheckServ) SaveBodyCheckInfo(checkNew model.TaBodyCheck) (*model.TaBodyCheck, error) {
	checkNews, err := s.dao.SaveBodyCheckInfo(checkNew)
	if err != nil {
		utils.LogError("用户体检信息新增失败: " + err.Error())
		return nil, errors.New("用户体检信息新增失败")
	}
	return checkNews, nil
}
func (s *BodycheckServ) GetCaseEquipment(EquipmentID string) (*model.TaCaseEquipment, error) {
	caseEquipment, err := s.dao.GetCaseEquipment(EquipmentID)
	if err != nil {
		utils.LogError("获取设备案场信息失败: " + err.Error())
		return nil, errors.New("获取设备案场信息失败")
	}
	return caseEquipment, nil
}
func (s *BodycheckServ) GetUserByOpenID(openid string) (*model.TaCustomer, error) {
	customer, err := s.dao.GetUserByOpenID(openid)
	if err != nil {
		utils.LogError("根据openid获取用户信息失败: " + err.Error())
		return nil, errors.New("根据openid获取用户信息失败")
	}
	return customer, nil
}

func (s *BodycheckServ) GetPresentationByCheckID(checkID int) ([]bodycheck.Presentation, error) {
	presentations, err := s.dao.GetPresentationByCheckID(checkID)
	if err != nil {
		utils.LogError("根据体检ID获取项目信息失败: " + err.Error())
		return nil, errors.New("根据体检ID获取项目信息失败")
	}
	return presentations, nil
}

func (s *BodycheckServ) GetDetailsByPresentID(ID int) ([]model.TaPresentationDetail, error) {
	detail, err := s.dao.GetDetailsByPresentID(ID)
	if err != nil {
		utils.LogError("根据项目ID获取详情失败: " + err.Error())
		return nil, errors.New("根据项目ID获取详情失败")
	}
	return detail, nil
}

func (s *BodycheckServ) GetPresentation(checkID, typeID int) (*model.TaPresentation, error) {
	presentation, err := s.dao.GetPresentation(checkID, typeID)
	if err != nil {
		utils.LogError("获取体检项目信息失败: " + err.Error())
		return nil, errors.New("获取体检项目信息失败")
	}
	return presentation, nil
}

func (s *BodycheckServ) SavePresentation(info model.TaPresentation) (*model.TaPresentation, error) {
	presentation, err := s.dao.SavePresentation(info)
	if err != nil {
		utils.LogError("新增体检项目信息失败: " + err.Error())
		return nil, errors.New("新增体检项目信息失败")
	}
	return presentation, err
}
func (s *BodycheckServ) UpdatePresentation(info *model.TaPresentation) error {
	err := s.dao.UpdatePresentation(info)
	if err != nil {
		utils.LogError("更新体检项目信息失败: " + err.Error())
		return errors.New("更新体检项目信息失败")
	}
	return nil
}

func (s *BodycheckServ) SavePresentationDetail(details []model.TaPresentationDetail) error {
	err := s.dao.SavePresentationDetail(details)
	if err != nil {
		utils.LogError("保存体检项目明细失败: " + err.Error())
		return errors.New("保存体检项目明细失败")
	}
	return nil

}
func (s *BodycheckServ) DeletePresentionDetail(ID int) error {
	err := s.dao.DeletePresentionDetail(ID)
	if err != nil {
		utils.LogError("根据项目ID删除明细信息失败: " + err.Error())
		return errors.New("根据项目ID删除明细信息失败")
	}
	return nil
}
