package statistics

import (
	"errors"
	"spaceofcheng/services/service"
	"spaceofcheng/services/utils"
)

// CardCouponStatistics 获取卡券统计信息
func (s *StatisticsServ) CardCouponStatistics(caseids, ctype, name string, page, pageSize int) (map[string]interface{}, error) {
	if pageSize == 0 {
		pageSize = service.PAGENUM
	}
	if page == 0 {
		page = 1
	}

	if caseids == "" {
		return nil, errors.New("请先选择案场信息")
	}

	list, err := s.dao.CardCouponStatistics(caseids, ctype, name, page, pageSize)
	if err != nil {
		utils.LogError("获取卡券统计数据失败: " + err.Error())
		return nil, errors.New("获取卡券统计数据失败")
	}
	total, err := s.dao.CardCouponStatisticsCount(caseids, ctype, name)
	if err != nil {
		utils.LogError("获取卡券统计数据失败: " + err.Error())
		return nil, errors.New("获取卡券统计数据失败")
	}

	return map[string]interface{}{
		"list":     list,
		"pagesize": pageSize,
		"pagenum":  total,
		"page":     page,
	}, nil
}

// CardCouponUsedStatistics 获取卡券使用统计信息
func (s *StatisticsServ) CardCouponUsedStatistics(caseids, tel, name, receivetype, begindate, enddate, status string, page, pageSize int) (map[string]interface{}, error) {
	if pageSize == 0 {
		pageSize = service.PAGENUM
	}
	if page == 0 {
		page = 1
	}

	if caseids == "" {
		return nil, errors.New("请先选择案场信息")
	}

	list, err := s.dao.CardCouponUsedStatistics(caseids, tel, name, receivetype, begindate, enddate, status, page, pageSize)
	if err != nil {
		utils.LogError("获取卡券统计数据失败: " + err.Error())
		return nil, errors.New("获取卡券统计数据失败")
	}
	total, err := s.dao.CardCouponUsedCountStatistics(caseids, tel, name, receivetype, begindate, enddate, status)
	if err != nil {
		utils.LogError("获取卡券统计数据失败: " + err.Error())
		return nil, errors.New("获取卡券统计数据失败")
	}

	return map[string]interface{}{
		"list":     list,
		"pagesize": pageSize,
		"pagenum":  total,
		"page":     page,
	}, nil
}

// CardCouponVerifyStatistics 获取卡券使用统计信息
func (s *StatisticsServ) CardCouponVerifyStatistics(caseids, tel, name, status string, page, pageSize int) (map[string]interface{}, error) {
	if pageSize == 0 {
		pageSize = service.PAGENUM
	}
	if page == 0 {
		page = 1
	}

	if caseids == "" {
		return nil, errors.New("请先选择案场信息")
	}

	list, err := s.dao.CardCouponVerifyStatistics(caseids, tel, name, status, page, pageSize)
	if err != nil {
		utils.LogError("获取卡券统计数据失败: " + err.Error())
		return nil, errors.New("获取卡券统计数据失败")
	}
	total, err := s.dao.CardCouponVerifyStatisticsCount(caseids, tel, name, status)
	if err != nil {
		utils.LogError("获取卡券统计数据失败: " + err.Error())
		return nil, errors.New("获取卡券统计数据失败")
	}

	return map[string]interface{}{
		"list":     list,
		"pagesize": pageSize,
		"pagenum":  total,
		"page":     page,
	}, nil
}
