package statistics

import (
	"errors"
	"spaceofcheng/services/service"
	"spaceofcheng/services/utils"
)

// GetCourseOrdersStatistics 获取课程订单统计信息
func (s *StatisticsServ) GetCourseOrdersStatistics(typeid, caseids, name, begindate, enddate string, page, pageSize int) (map[string]interface{}, error) {
	if pageSize == 0 {
		pageSize = service.PAGENUM
	}
	if page == 0 {
		page = 1
	}

	if caseids == "" {
		return nil, errors.New("请先选择案场信息")
	}

	list, err := s.dao.GetCourseOrdersStatistics(typeid, caseids, name, begindate, enddate, page, pageSize)
	if err != nil {
		utils.LogError("获取课程订单统计数据失败: " + err.Error())
		return nil, errors.New("获取课程订单统计数据失败")
	}
	total, err := s.dao.GetCourseOrdersStatisticsCount(typeid, caseids, name, begindate, enddate)
	if err != nil {
		utils.LogError("获取课程订单统计数据失败: " + err.Error())
		return nil, errors.New("获取课程订单统计数据失败")
	}

	return map[string]interface{}{
		"list":     list,
		"pagesize": pageSize,
		"pagenum":  total,
		"page":     page,
	}, nil
}

// GetCourseStatistics 获取课程统计信息
func (s *StatisticsServ) GetCourseStatistics(typeid, caseids, name string, page, pageSize int) (map[string]interface{}, error) {
	if pageSize == 0 {
		pageSize = service.PAGENUM
	}
	if page == 0 {
		page = 1
	}

	if caseids == "" {
		return nil, errors.New("请先选择案场信息")
	}

	list, err := s.dao.GetCourseStatistics(typeid, caseids, name, page, pageSize)
	if err != nil {
		utils.LogError("获取课程统计数据失败: " + err.Error())
		return nil, errors.New("获取课程统计数据失败")
	}
	total, err := s.dao.GetCourseStatisticsCount(typeid, caseids, name)
	if err != nil {
		utils.LogError("获取课程统计数据失败: " + err.Error())
		return nil, errors.New("获取课程统计数据失败")
	}

	return map[string]interface{}{
		"list":     list,
		"pagesize": pageSize,
		"pagenum":  total,
		"page":     page,
	}, nil
}
